pub struct Props {
pub src: AttrValue,
pub onclick: Option<Callback<MarkdownMouseEvent, ()>>,
pub render_links: Option<Callback<LinkDescription<Html>, Html>>,
pub theme: Option<&'static str>,
pub wikilinks: bool,
pub hard_line_breaks: bool,
pub parse_options: Option<Options>,
pub components: CustomComponents,
pub frontmatter: Option<UseStateHandle<String>>,
pub send_debug_info: Option<Callback<Vec<String>>>,
}Fields
src: AttrValueonclick: Option<Callback<MarkdownMouseEvent, ()>>render_links: Option<Callback<LinkDescription<Html>, Html>>theme: Option<&'static str>wikilinks: boolhard_line_breaks: boolparse_options: Option<Options>components: CustomComponentsfrontmatter: Option<UseStateHandle<String>>send_debug_info: Option<Callback<Vec<String>>>Trait Implementations
Sourceimpl<'a> Context<'a, 'static> for &'a Props
impl<'a> Context<'a, 'static> for &'a Props
type View = VNode
type Handler<T: 'static> = Callback<T>
type MouseEvent = MouseEvent
Sourcefn props(self) -> MarkdownProps
fn props(self) -> MarkdownProps
get all the properties from the context
Sourcefn el_with_attributes(
self,
e: HtmlElement,
inside: Self::View,
attributes: ElementAttributes<Callback<MouseEvent>>,
) -> Self::View
fn el_with_attributes( self, e: HtmlElement, inside: Self::View, attributes: ElementAttributes<Callback<MouseEvent>>, ) -> Self::View
creates a html element
attributes contains the html attributes for this elementSourcefn el_span_with_inner_html(
self,
inner_html: String,
attributes: ElementAttributes<Callback<MouseEvent>>,
) -> Self::View
fn el_span_with_inner_html( self, inner_html: String, attributes: ElementAttributes<Callback<MouseEvent>>, ) -> Self::View
renders raw html, inside a span
Sourcefn el_hr(
self,
attributes: ElementAttributes<Callback<MouseEvent>>,
) -> Self::View
fn el_hr( self, attributes: ElementAttributes<Callback<MouseEvent>>, ) -> Self::View
renders a
hr element, with attributesSourcefn el_fragment(self, children: Vec<Self::View>) -> Self::View
fn el_fragment(self, children: Vec<Self::View>) -> Self::View
takes a vector of views and return a view
Sourcefn mount_dynamic_link(
self,
rel: &str,
href: &str,
integrity: &str,
crossorigin: &str,
)
fn mount_dynamic_link( self, rel: &str, href: &str, integrity: &str, crossorigin: &str, )
add a styleshit to the markdown component
fn el_input_checkbox( self, checked: bool, attributes: ElementAttributes<Callback<MouseEvent>>, ) -> Self::View
Sourcefn call_handler<T: 'static>(callback: &Self::Handler<T>, input: T)
fn call_handler<T: 'static>(callback: &Self::Handler<T>, input: T)
calls a callback with the given input
Sourcefn make_md_handler(
self,
position: Range<usize>,
stop_propagation: bool,
) -> Self::Handler<MouseEvent>
fn make_md_handler( self, position: Range<usize>, stop_propagation: bool, ) -> Self::Handler<MouseEvent>
creates a callback that will fire when the user clicks on markdown
fn has_custom_links(self) -> bool
fn render_links(self, link: LinkDescription<Html>) -> Result<Html, String>
Sourcefn set_frontmatter(&mut self, frontmatter: String)
fn set_frontmatter(&mut self, frontmatter: String)
write the frontmatter (or metadata) string
present at the top of the markdown source
fn has_custom_component(self, name: &str) -> bool
fn render_custom_component( self, name: &str, input: MdComponentProps, ) -> Result<Self::View, ComponentCreationError>
Sourcefn el(self, e: HtmlElement, inside: Self::View) -> Self::View
fn el(self, e: HtmlElement, inside: Self::View) -> Self::View
creates a html element, with default attributes
fn render_tasklist_marker(self, m: bool, position: Range<usize>) -> Self::View
fn render_rule(self, range: Range<usize>) -> Self::View
fn render_code(self, s: CowStr<'a>, range: Range<usize>) -> Self::View
fn render_text(self, s: CowStr<'a>, range: Range<usize>) -> Self::View
fn render_link( self, link: LinkDescription<Self::View>, ) -> Result<Self::View, String>
Sourceimpl Properties for Props
impl Properties for Props
impl StructuralPartialEq for Props